<?php
/*
Plugin Name: Eventr
Plugin URI: http://www.bin-co.com/tools/wordpress/plugins/eventr/
Description: Eventr Plugin lets you create events and provides your visitors with a form that lets them register for the event. There is also an option to show the entire attendee list to blog vistors as well.
Version: 1.00.0
Author: Binny V A
Author URI: http://www.binnyva.com/
*/

/**
 * Add a new menu under Manage, visible for all users with template viewing level.
 */
add_action( 'admin_menu', 'eventr_add_menu_links' );
function eventr_add_menu_links() {
	$view_level= 2;
	add_submenu_page( 'edit.php', __('Manage Events'), 
		__('Manage Events'), $view_level, 
		'eventr/events.php' );
}

/**
 * This will scan all the content pages that wordpress outputs for our special code. If the code is found, it will replace the requested quiz.
 */
add_filter('the_content', 'eventr_scan_content');
function eventr_scan_content($body) {
	if(strpos($body, 'EVENTR') !== false) {
		if(preg_match('/<!--\s*EVENTR\s*REGISTRATION\s*(\d+)\s*-->/', $body, $matches)) {
			$event_id = $matches[1];
			
			if(is_numeric($event_id)) { // Basic validiation - more on the show_quiz.php file.
				ob_start();
				include(ABSPATH . 'wp-content/plugins/eventr/show_registeration_form.php');
				$contents = ob_get_contents();
				ob_end_clean();
		
				$body = str_replace($matches[0], $contents, $body);
			}
		}
		// Don't put elseif here - the blog auther might put both tags into the same page.
		if(preg_match('/<!--\s*EVENTR\s*ATTENDEES\s*(\d+)\s*-->/', $body, $matches)) {
			$event_id = $matches[1];
			
			if(is_numeric($event_id)) { // Basic validiation - more on the show_quiz.php file.
				ob_start();
				include(ABSPATH . 'wp-content/plugins/eventr/show_attendee_list.php');
				$contents = ob_get_contents();
				ob_end_clean();
		
				$body = str_replace($matches[0], $contents, $body);
			}
		}
	}
	
	return $body;
}

/**
 * Creates tables and upload folder on activation.
 */
add_action('activate_eventr/eventr.php','eventr_activate');
function eventr_activate() {
	global $wpdb;
	
	//Create the folder to which the images will be uploaded to...
	$images_folder = ABSPATH . get_option('upload_path') . '/eventr/';
	if ( ! file_exists($images_folder) && ! @mkdir($images_folder, 0777) ) {
		print '<div class="updated error"><p><strong>Cannot create the images folder "'.$images_folder.'". Please create it using FTP and give it 777 permission</strong></p></div>';
	}
	
	// Create the table structure
	$wpdb->query("CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}eventr_attendee` (
		`ID` int(11) unsigned NOT NULL auto_increment,
		`name` varchar(50) NOT NULL,
		`description` mediumtext NOT NULL,
		`url` varchar(255) NOT NULL,
		`email` varchar(100) NOT NULL,
		`phone` varchar(20) NOT NULL,
		`picture` varchar(200) NOT NULL,
		PRIMARY KEY  (`ID`)
		);");


	$wpdb->query("CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}eventr_event` (
		`ID` int(11) unsigned NOT NULL auto_increment,
		`name` varchar(50) NOT NULL,
		`description` mediumtext NOT NULL,
		`event_date` date NOT NULL,
		`added_on` datetime NOT NULL,
		`status` enum('1','0') NOT NULL default '1',
		PRIMARY KEY  (`ID`)
		);");
		
		
	$wpdb->query("CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}eventr_event_attendee` (
		`event_ID` int(11) unsigned NOT NULL,
		`attendee_ID` int(11) unsigned NOT NULL,
		`added_on` datetime NOT NULL,
		`guests` int(2) NOT NULL default '0',
		KEY `event_ID` (`event_ID`,`attendee_ID`)
		);");

}
